@@ -49,7 +49,7 @@
 /* #undef WITH_FAAC */
 /* #undef WITH_SOXR */
 #define WITH_GFX_H264
-#define WITH_OPENH264
+/* #undef WITH_OPENH264 */
 /* #undef WITH_OPENH264_LOADING */
 #define WITH_VIDEO_FFMPEG
 /* #undef WITH_DSP_EXPERIMENTAL */
@@ -62,7 +62,7 @@
 
 #define WITH_CHANNELS
 #define WITH_CLIENT_CHANNELS
-#define WITH_SERVER_CHANNELS
+/* #undef WITH_SERVER_CHANNELS */
 
 /* #undef WITH_CHANNEL_GFXREDIR */
 /* #undef WITH_CHANNEL_RDPAPPLIST */
@@ -222,7 +222,7 @@
 /* #undef WITH_DEBUG_RINGBUFFER */
 
 /* Proxy */
-#define WITH_PROXY_MODULES
+/* #undef WITH_PROXY_MODULES */
 /* #undef WITH_PROXY_EMULATE_SMARTCARD */
 
 /** If defined linux/vm_sockets.h support is available.
